<?php
/**
 * Plugin Name: Tickera - Remove fees for 100% discount
 * Plugin URI: http://tickera.com/
 * Description: Unofficial add-on: Remove fees for 100% discount codes
 * Author: Tickera.com
 * Author URI: http://tickera.com/
 * Version: 2.0
 * TextDomain: tc
 * Domain Path: /languages/
 * Copyright 2012-2016 Tickera (http://tickera.com/)
 */

if ( ! class_exists( 'TC_Remove_Fees_For_One_Hundred_Percent_Discount' ) ) {

    class TC_Remove_Fees_For_One_Hundred_Percent_Discount {

        var $version = '2.0';
        var $title = 'Tickera - Remove fees for 100% discount';
        var $name = 'custom-zero-fees-for-100-percent-discounts';
        var $dir_name = 'custom-zero-fees-for-100-percent-discounts';
        var $location = 'plugins';
        var $plugin_dir = '';
        var $plugin_url = '';

        function __construct() {
            self::init_vars();
            add_action( 'activated_plugin', array( $this, 'load_this_plugin_the_very_last' ) );
            add_action( 'tc_cart_col_value_before_total_price_discount', array( $this, 'tc_cart_col_value_before_total_price_discount_modify_fees_value' ), 999, 1 );
            add_action( 'tc_order_created', array( $this, 'update_cart_info_data' ), 11, 5 );
        }

        function init_vars() {

            if ( defined( 'WP_PLUGIN_URL' ) && defined( 'WP_PLUGIN_DIR' ) && file_exists( WP_PLUGIN_DIR . '/' . $this->dir_name . '/' . basename( __FILE__ ) ) ) {
                $this->location = 'subfolder-plugins';
                $this->plugin_dir = WP_PLUGIN_DIR . '/' . $this->dir_name . '/';
                $this->plugin_url = plugins_url( '/', __FILE__ );

            } elseif ( defined( 'WP_PLUGIN_URL' ) && defined( 'WP_PLUGIN_DIR' ) && file_exists( WP_PLUGIN_DIR . '/' . basename( __FILE__ ) ) ) {
                $this->location = 'plugins';
                $this->plugin_dir = WP_PLUGIN_DIR . '/';
                $this->plugin_url = plugins_url( '/', __FILE__ );

            } elseif ( is_multisite() && defined( 'WPMU_PLUGIN_URL' ) && defined( 'WPMU_PLUGIN_DIR' ) && file_exists( WPMU_PLUGIN_DIR . '/' . basename( __FILE__ ) ) ) {
                $this->location = 'mu-plugins';
                $this->plugin_dir = WPMU_PLUGIN_DIR;
                $this->plugin_url = WPMU_PLUGIN_URL;

            } else {
                wp_die( sprintf( __( 'There was an issue determining where %s is installed. Please reinstall it.', 'tc' ), $this->title ) );
            }
        }

        /**
         * Modify plugin load sequence.
         * Make sure to load dependencies first.
         * @param string $path
         */
        function load_this_plugin_the_very_last( $path = '' ) {

            if ( ! $path ) {
                $path = $this->dir_name . '/' . basename( __FILE__ );
            }

            if ( $plugins = get_option( 'active_plugins' ) ) {
                if ( $key = array_search( $path, $plugins ) ) {
                    unset( $plugins[ $key ] );
                    $plugins[] = $path;
                    update_option( 'active_plugins', array_values( $plugins ) );
                }
            }
        }

        function tc_cart_col_value_before_total_price_discount_modify_fees_value() {

            global $tc, $total_fees;

            $tc->session->start();
            $tc_cart_subtotal = $tc->session->get( 'tc_cart_subtotal' );
            $discount_value_total = $tc->session->get( 'discount_value_total' );

            if ( ! is_null( $tc_cart_subtotal ) && ! is_null( $discount_value_total ) ) {

                if ( (float) $discount_value_total >= (float) $tc_cart_subtotal ) {
                    $total_fees = 0;
                    $tc->session->set( 'tc_total_fees', 0 );
                }
            }
        }

        function update_cart_info_data( $order_id, $status, $cart_contents, $cart_info, $payment_info ) {

            global $tc;
            $tc->session->start();
            $tc_cart_subtotal = $tc->session->get( 'tc_cart_subtotal' );
            $discount_value_total = $tc->session->get( 'discount_value_total' );

            if ( ! is_null( $tc_cart_subtotal ) && ! is_null( $discount_value_total ) ) {

                if ( (float) $discount_value_total >= (float) $tc_cart_subtotal ) {

                    $order = tc_get_order_id_by_name( $order_id );
                    $order_id = $order->ID;

                    /**
                     * Update Order Meta
                     * Update ticket_fee_post_meta with zero value
                     */
                    $owner_data = isset( $cart_info[ 'owner_data' ] ) ? $cart_info[ 'owner_data' ] : [];
                    if ( $owner_data[ 'ticket_fee_post_meta' ] ) {
                        foreach ( $owner_data[ 'ticket_fee_post_meta' ] as $key => $fees ) {
                            foreach ( $fees as $_key => $fee ) {
                                $owner_data[ 'ticket_fee_post_meta' ][ $key ][ $_key ] = 0;
                            }
                        }
                        $cart_info[ 'owner_data' ] = $owner_data;
                    }
                    update_post_meta( $order_id, 'tc_cart_info', $cart_info );

                    /**
                     * Update Tickets Instances Fee Meta
                     */
                    $ticket_ids = get_posts( [
                        'post_type' => 'tc_tickets_instances',
                        'post_parent' => $order_id,
                        'fields' => 'ids',
                        'posts_per_page' => -1
                    ] );

                    foreach ( $ticket_ids as $ticket_id ) {
                        update_post_meta( $ticket_id, 'ticket_fee', 0 );
                    }
                }
            }
        }
    }

    new TC_Remove_Fees_For_One_Hundred_Percent_Discount();
}
